.. -*- mode: rst -*-

Authors
=======

  * Alexandre Gramfort 2011-2013
  * Matti Hamalainen 2011-2013
  * Emily Ruzich 2011
  * Martin Luessi 2011-2013
  * Christian Brodbeck 2012-2013
  * Louis Thibault 2012
  * Eric Larson 2012-2013
  * Denis A. Engemann 2012-2013
  * Daniel Strohmeier 2012
  * Brad Buran 2013
  * Simon Kornblith 2013
  * Mainak Jas 2013
  * Roman Goj 2013
  * Teon Brooks 2013
